@@ -145,6 +145,7 @@ class SQLCli(object):
         self.KafkaHandler = KafkaWrapper()        # 函数句柄，处理Kafka的消息
         self.SpoolFileHandler = None              # 当前Spool文件句柄
         self.AppOptions = None                    # 应用程序的配置参数
+        self.Encoding = None                      # 应用程序的Encoding信息
         self.prompt_app = None                    # PromptKit控制台
         self.db_conn = None                       # 当前应用的数据库连接句柄
         if WorkerName is None:
@@ -1700,6 +1701,8 @@ class SQLCli(object):
             self.echo("Can not open inifile for read [" + m_conf_filename + "]", err=True, fg="red")
             return False
 
+        # 读取程序默认的Encoding信息
+
         # 打开输出日志, 如果打开失败，就直接退出
         try:
             if self.logfilename is not None:
